@@ -2,8 +2,9 @@ from typing import Any, cast
 
 from django.apps import AppConfig, apps
 from django.utils.translation import gettext_lazy as _
-from injector import Injector
+from injector import Injector, Module
 
+from ninja_extra.conf import settings
 from ninja_extra.modules import NinjaExtraModule
 from ninja_extra.shortcuts import fail_silently
 
@@ -16,7 +17,7 @@ class NinjaExtraConfig(AppConfig):
 
     def ready(self) -> None:
         self.injector = Injector([NinjaExtraModule])
-        # get django_injector is available and registered
+        # get django_injector is available or registered
         django_injector_app = fail_silently(
             apps.get_app_config, app_label="django_injector"
         )
@@ -24,3 +25,10 @@ class NinjaExtraConfig(AppConfig):
         if app:
             app.ready()
             self.injector = app.injector
+        self.register_injector_modules()
+
+    def register_injector_modules(self) -> None:
+        for module in settings.INJECTOR_MODULES:
+            if isinstance(module, type) and issubclass(module, Module):
+                module = module()
+            self.injector.binder.install(module)
