@@ -1,9 +1,24 @@
 import inspect
 from functools import wraps
-from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, Tuple, Type
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Tuple,
+    Type,
+    Union,
+)
 
 from django.core.exceptions import ImproperlyConfigured
-from django.http import HttpRequest
+from django.http.request import HttpRequest
+from ninja.types import DictStrAny
+
+from ninja_extra.controllers.response import ControllerResponse
+from ninja_extra.permissions import BasePermission
+from ninja_extra.permissions.base import OperandHolder
 
 from ...dependency_resolver import get_injector
 
@@ -11,6 +26,21 @@ if TYPE_CHECKING:
     from ...controllers import APIController, Route
 
 
+class RouteFunctionContext:
+    permission_classes: Union[
+        List[Type[BasePermission]], List[OperandHolder[Any]], List
+    ] = []
+    request: Optional[HttpRequest] = None
+    args: List[Any] = []
+    kwargs: DictStrAny = dict()
+
+    def __init__(self, **kwargs: Any) -> None:
+        self.permission_classes = kwargs.get("permission_classes", [])
+        self.request = kwargs.get("request")
+        self.args = kwargs.get("args", [])
+        self.kwargs = kwargs.get("kwargs", dict())
+
+
 class RouteFunction(object):
     def __init__(
         self, route: "Route", controller: Optional[Type["APIController"]] = None
@@ -31,7 +61,7 @@ class RouteFunction(object):
         for parameter in sig_inspect.parameters.values():
             if parameter.name not in skip_parameters:
                 sig_parameter.append(parameter)
-            if parameter.name == "request":
+            elif parameter.name == "request":
                 self.has_request_param = True
         return sig_inspect, sig_parameter
 
@@ -52,10 +82,22 @@ class RouteFunction(object):
 
             if self.has_request_param:
                 api_func_kwargs.update(request=request)
-            return self.route.view_func(controller_instance, *args, **api_func_kwargs)
+            return self._process_view_function_result(
+                self.route.view_func(controller_instance, *args, **api_func_kwargs)
+            )
 
         return as_view
 
+    def _process_view_function_result(self, result: Any) -> Any:
+        """
+        This process any an returned value from view_func
+        and creates an api response if result is ControllerResponseSchema
+        """
+
+        if result and isinstance(result, ControllerResponse):
+            return result.status_code, result.convert_to_schema()
+        return result
+
     def _get_controller_instance(
         self, request: HttpRequest, *args: Any, **kwargs: Any
     ) -> "APIController":
@@ -65,9 +107,7 @@ class RouteFunction(object):
         assert self.controller
         controller_instance: "APIController" = injector.create_object(self.controller)
 
-        for k, v in init_kwargs.items():
-            if hasattr(controller_instance, k):
-                setattr(controller_instance, k, v)
+        controller_instance.context = RouteFunctionContext(**init_kwargs)
         return controller_instance
 
     def _get_controller_init_kwargs(
@@ -104,9 +144,10 @@ class AsyncRouteFunction(RouteFunction):
             api_func_kwargs = dict(**kwargs)
             if self.has_request_param:
                 api_func_kwargs.update(request=request)
-            return await self.route.view_func(
+            result = await self.route.view_func(
                 controller_instance, *args, **api_func_kwargs
             )
+            return self._process_view_function_result(result=result)
 
         return as_view
 
